@@ -13,27 +13,23 @@
 
 #include "barwidget.h"
 
-
 // Size constants for the collection widgets
-extern int COLLWIDTH;    // Width in pixels of a collection widget
-extern int COLLHEIGHT1;  // Height in pixels of a collection widget not yet fully learned
-extern int COLLHEIGHT2;  // Height in pixels of a collection widget fully learned
-
+extern int COLLWIDTH; // Width in pixels of a collection widget
+extern int COLLHEIGHT1; // Height in pixels of a collection widget not yet fully learned
+extern int COLLHEIGHT2; // Height in pixels of a collection widget fully learned
 
 class QLabel;
 class QPushButton;
 class RemoveButton;
 class Collection;
 
-
 class CollectionWidget : public QWidget
 {
     Q_OBJECT
 
 public:
-    CollectionWidget(Collection *collection, WordCount *dueWords,
-		     QWidget *parent = 0);
-    ~CollectionWidget();
+    CollectionWidget(Collection *collection, WordCount *dueWords, QWidget *parent = 0);
+    ~CollectionWidget() override;
 
     Collection *collection() const;
     void setCollection(Collection *collection);
@@ -49,13 +45,13 @@ private:
     void fillWidget();
 
 private:
-    QLabel       *m_titleLabel;
-    QLabel       *m_thumbnail;
-    BarWidget    *m_barWidget;
+    QLabel *m_titleLabel;
+    QLabel *m_thumbnail;
+    BarWidget *m_barWidget;
     RemoveButton *m_removeButton;
-    QPushButton  *m_practiceButton;
+    QPushButton *m_practiceButton;
 
-    Collection   *m_collection;
+    Collection *m_collection;
 };
 
 #endif
